@@ -17,6 +17,7 @@
 #include <KAboutData>
 #include <KPageWidget>
 #include <kdeclarative/kdeclarative.h>
+#include <kdeclarative/kdeclarative_export.h>
 #include <kdeclarative/qmlobjectsharedengine.h>
 #include <kquickaddons/configmodule.h>
 
@@ -87,7 +88,7 @@ KCModuleQml::KCModuleQml(std::unique_ptr<KQuickAddons::ConfigModule> configModul
         setUseRootOnlyMessage(d->configModule->useRootOnlyMessage());
     });
 
-#ifndef KCONFIGWIDGETS_NO_KAUTH
+#if KCONFIGWIDGETS_WITH_KAUTH
     if (!d->configModule->authActionName().isEmpty()) {
         setAuthAction(KAuth::Action(d->configModule->authActionName()));
     }
@@ -97,8 +98,15 @@ KCModuleQml::KCModuleQml(std::unique_ptr<KQuickAddons::ConfigModule> configModul
 #endif
 
     connect(this, &KCModule::defaultsIndicatorsVisibleChanged, d->configModule.get(), &KQuickAddons::ConfigModule::setDefaultsIndicatorsVisible);
+
+#if QUICKADDONS_BUILD_DEPRECATED_SINCE(5, 88)
     // KCModule takes ownership of the kabout data so we need to force a copy
+    QT_WARNING_PUSH
+    QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
+    QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
     setAboutData(new KAboutData(*d->configModule->aboutData()));
+    QT_WARNING_POP
+#endif
     setFocusPolicy(Qt::StrongFocus);
 
     // Build the UI
@@ -147,10 +155,8 @@ Kirigami.ApplicationItem {
 
     pageStack.separatorVisible: false
     pageStack.globalToolBar.preferredHeight: toolButton.implicitHeight + Kirigami.Units.smallSpacing * 2
-    pageStack.globalToolBar.style: pageStack.wideMode && pageStack.columnView.columnResizeMode !== Kirigami.ColumnView.SingleColumn
-        ? Kirigami.ApplicationHeaderStyle.Titles
-        : Kirigami.ApplicationHeaderStyle.Breadcrumb
-    pageStack.globalToolBar.showNavigationButtons: true
+    pageStack.globalToolBar.style: Kirigami.ApplicationHeaderStyle.ToolBar
+    pageStack.globalToolBar.showNavigationButtons: pageStack.currentIndex > 0 ? Kirigami.ApplicationHeaderStyle.ShowBackButton : Kirigami.ApplicationHeaderStyle.NoNavigationButtons
 
     pageStack.columnView.columnResizeMode: pageStack.items.length > 0 && pageStack.items[0].Kirigami.ColumnView.fillWidth
         ? Kirigami.ColumnView.SingleColumn
@@ -214,7 +220,6 @@ Kirigami.ApplicationItem {
     }
 
     layout->addWidget(d->quickWidget);
-    layout->setContentsMargins(0, 0, 0, 0);
 }
 
 KCModuleQml::~KCModuleQml()
@@ -258,7 +263,7 @@ void KCModuleQml::focusInEvent(QFocusEvent *event)
 
 QSize KCModuleQml::sizeHint() const
 {
-    if (!d->configModule->mainUi()) {
+    if (!d->rootPlaceHolder) {
         return QSize();
     }
 
@@ -270,10 +275,18 @@ QString KCModuleQml::quickHelp() const
     return d->configModule->quickHelp();
 }
 
+#if KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(5, 90)
 const KAboutData *KCModuleQml::aboutData() const
 {
+#if QUICKADDONS_BUILD_DEPRECATED_SINCE(5, 88)
+    QT_WARNING_PUSH
+    QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
+    QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
     return d->configModule->aboutData();
+    QT_WARNING_POP
+#endif
 }
+#endif
 
 void KCModuleQml::load()
 {
